package com.nextfaze.appsynclibraryproject

import android.content.Context
import com.amazonaws.amplify.generated.graphql.ListTodosQuery
import com.amazonaws.mobile.config.AWSConfiguration
import com.amazonaws.mobileconnectors.appsync.AWSAppSyncClient
import com.apollographql.apollo.CustomTypeAdapter
import com.apollographql.apollo.GraphQLCall
import com.apollographql.apollo.api.Response
import com.apollographql.apollo.exception.ApolloException
import org.threeten.bp.ZonedDateTime
import type.CustomType

class AppSync(context: Context) {

    private val client = AWSAppSyncClient.builder()
        .context(context)
        .addCustomTypeAdapter(CustomType.AWSDATETIME, ZonedDateTimeAdapter)
        .awsConfiguration(AWSConfiguration(context))
//        .cognitoUserPoolsAuthProvider { mobileClient.tokens.idToken.tokenString }
        .build()

    fun run() {
        client.query(ListTodosQuery.builder().limit(5).build()).enqueue(object : GraphQLCall.Callback<ListTodosQuery.Data>() {
            override fun onResponse(response: Response<ListTodosQuery.Data>) {
                val zonedDateTime: ZonedDateTime? = response.data()?.listTodos()?.items()?.first()?.created()
            }

            override fun onFailure(e: ApolloException) {
            }
        })
    }
}

private object ZonedDateTimeAdapter : CustomTypeAdapter<ZonedDateTime> {
    override fun encode(value: ZonedDateTime): String = value.toString()
    override fun decode(value: String): ZonedDateTime = ZonedDateTime.parse(value)
}
